@@ -1,9 +1,9 @@
 package methods;
 use 5.008;
-our $VERSION = '0.03';
+our $VERSION = '0.10';
 
 use true;
-use namespace::autoclean;
+use namespace::sweep;
 use Method::Signatures::Simple;
 our @ISA = 'Method::Signatures::Simple';
 
@@ -14,7 +14,7 @@ method import {
     }
 
     true->import;
-    namespace::autoclean->import( -cleanee => scalar(caller) );
+    namespace::sweep->import( -cleanee => scalar(caller) );
     Method::Signatures::Simple->import( @_, into => scalar(caller) );
 
     if ($want_invoker) {
@@ -30,7 +30,7 @@ __END__
 
 =head1 NAME
 
-methods - Provide method syntax and autoclean namespaces
+methods - Provide method syntax and sweep namespaces
 
 =head1 SYNOPSIS
 
@@ -61,7 +61,7 @@ With L<invoker> support:
 This module uses L<Method::Signatures::Simple> to provide named and
 anonymous methods with parameters, except with a shorter module name.
 
-It also imports L<namespace::autoclean> so the C<method> helper function
+It also imports L<namespace::sweep> so the C<method> helper function
 (as well as any imported helper functions) won't become methods in the
 importing module.
 
